@@ -13,6 +13,7 @@ timePlot <- function(mydata,
                      cols = "brewer1",
                      main = "",
                      ylab = pollutant,
+                     plot.type = "l",
                      lty = 1:length(pollutant),
                      lwd = 1,
                      pch = NA,
@@ -94,15 +95,7 @@ timePlot <- function(mydata,
     if (date.pad) mydata <- date.pad(mydata, type)
 
     mydata <- cutData(mydata, type)
-
-    ## The aim to to get colums "date", "site" then turn to column data using melt
-    ## Finally end up with "date", "value", "variable"
-
-    ## don't need type, now a condition
-    vars <-  c(vars, "cond")
-    vars <- vars[vars != type]
-    mydata <- mydata[, vars]
-    mydata <- rename(mydata, c(cond = "site")) ## change to name "site"
+ 
 
     ## average the data if necessary (default does nothing)
     if (avg.time != "default") {
@@ -110,21 +103,24 @@ timePlot <- function(mydata,
         
         if (length(percentile) > 1) {
 
-            mydata <- ddply(mydata, .(site), calcPercentile, pollutant = pollutant, period = avg.time,
+             mydata <- ddply(mydata, type, calcPercentile, pollutant = pollutant, period = avg.time,
                             data.thresh = data.thresh, percentile = percentile)
+             
             pollutant <-  paste("percentile.", percentile,  sep = "")
-            vars <- names(mydata) ## new variables to use
+       #     vars <- names(mydata) ## new variables to use
             if (missing(group)) group <- TRUE        
 
         } else {
-            
-            mydata <- timeAverage(mydata, period = avg.time, data.thresh = data.thresh,
-                                  statistic = statistic, percentile = percentile)
+          
+             mydata <- ddply(mydata, type, timeAverage, period = avg.time, statistic = statistic,
+                        percentile = percentile, data.thresh = data.thresh)    
         }
         
     }
-    
-    mydata <- melt(mydata, id.var = c("date", "site"))
+   
+    mydata <- melt(mydata, id.var = c("date", type))
+
+  
     if (type != "default") {
         
         group <- TRUE ## need to group pollutants if conditioning
@@ -163,7 +159,8 @@ timePlot <- function(mydata,
     myColors <- openColours(cols, npol)
 
     ## basic function for lattice call + defaults
-    myform <- formula("value ~ date | site")
+     myform <- formula(paste("value ~ date |", type))
+   
     strip <- TRUE
     strip.left <- FALSE
     dates <- dateBreaks(mydata$date, date.breaks)$major ## for date scale
@@ -250,6 +247,7 @@ timePlot <- function(mydata,
            pch = pch,
            xlim = xlim,
            main = quickText(main),
+           par.strip.text = list(cex = 0.8),
            ylab = quickText(ylab, auto.text),
            scales = scales,
            key = key,
@@ -270,7 +268,7 @@ timePlot <- function(mydata,
                    panel.grid(-1, 0)
                }
 
-               panel.xyplot(x, y, type = "l", lty = lty, lwd = lwd, col.line = myColors[group.number],...)
+               panel.xyplot(x, y, type = plot.type, lty = lty, lwd = lwd, col.line = myColors[group.number],...)
                ## deal with points separately - useful if missing data where line does not join consequtive points
                if (any(!is.na(pch))) {                   
                    lpoints(x, y, type = "p", pch = pch, col.symbol = myColors[group.number],...)
